@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERCLAWSMAILTEST_H
-#define FILTERCLAWSMAILTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void canNotImportDataWhenHomeDirSelected();
 };
 
-#endif // FILTERCLAWSMAILTEST_H
