@@ -2,7 +2,7 @@
   filterkmail_maildir.h  -  Kmail maildir mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,7 +31,7 @@ private:
 
     void importDirContents(const QString &);
     void importFiles(const QString &);
-    FilterKMail_maildirPrivate *const d;
+    std::unique_ptr<FilterKMail_maildirPrivate> const d;
 };
 }
 
