@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILIMPORTER_FILTER_MAILMANGZIP_H
-#define MAILIMPORTER_FILTER_MAILMANGZIP_H
+#pragma once
 
 #include "filters.h"
 
@@ -26,4 +25,3 @@ public:
 };
 }
 
-#endif
