@@ -2,7 +2,7 @@
   filtersylpheed.h  -  Sylpheed maildir mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -44,7 +44,7 @@ private:
 
     void readMarkFile(const QString &, QHash<QString, unsigned long> &);
     MailImporter::MessageStatus msgFlagsToString(unsigned long flags);
-    FilterSylpheedPrivate *const d;
+    std::unique_ptr<FilterSylpheedPrivate> const d;
 };
 }
 
