@@ -2,13 +2,12 @@
   filterthebat.h  -  TheBat! mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILIMPORTER_FILTER_THEBAT_H
-#define MAILIMPORTER_FILTER_THEBAT_H
+#pragma once
 
 #include "filters.h"
 #include "mailimporter_export.h"
@@ -32,8 +31,7 @@ private:
     void importDirContents(const QString &);
     void importFiles(const QString &);
     void processDirectory(const QString &path);
-    FilterTheBatPrivate *const d;
+    std::unique_ptr<FilterTheBatPrivate> const d;
 };
 }
 
-#endif
